#include <cmath>
#include <iostream>
#include <utility>

using namespace std;

int L, W;
double X, Y, Ws;

int nrIndices() { return L + L + W + W; }
int mod(int i, int m) { int r = i % m; return r < 0 ? r + m : r; }
int clamp(int i) { return mod(i, nrIndices()); }

struct point { point(double x, double y) : x(x), y(y) {} double x; double y;
bool almostEqual(point other) { return abs(x - other.x) < 1e-5 && abs(y - other.y) < 1e-5; }
friend ostream& operator<<(ostream& o, point p) { return o << "(" << p.x << ", " << p.y << ")"; } };
struct linePiece { linePiece(point a, point b) : a(a), b(b) {} point a; point b; friend ostream& operator<<(ostream& o, linePiece p) { return o << "(" << p.a << ", " << p.b << ")"; } };
point lineLineIntersection(linePiece l1, linePiece l2) {
	return point(((l1.a.x*l1.b.y-l1.a.y*l1.b.x)*(l2.a.x-l2.b.x)-(l1.a.x-l1.b.x)*(l2.a.x*l2.b.y-l2.a.y*l2.b.x)) / ((l1.a.x-l1.b.x)*(l2.a.y-l2.b.y)-(l1.a.y-l1.b.y)*(l2.a.x-l2.b.x))
	,((l1.a.x*l1.b.y-l1.a.y*l1.b.x)*(l2.a.y-l2.b.y)-(l1.a.y-l1.b.y)*(l2.a.x*l2.b.y-l2.a.y*l2.b.x)) / ((l1.a.x-l1.b.x)*(l2.a.y-l2.b.y)-(l1.a.y-l1.b.y)*(l2.a.x-l2.b.x)));
}
bool intersectHor(linePiece l, linePiece horizontalFacingRight) {
	point iPoint = lineLineIntersection(l, horizontalFacingRight);
	bool result = (iPoint.x >= horizontalFacingRight.a.x && iPoint.x <= horizontalFacingRight.b.x)
	|| (iPoint.x >= horizontalFacingRight.b.x && iPoint.x <= horizontalFacingRight.a.x);
	//if (result) cerr << "horizontal " << iPoint << endl;
	return result;
}
bool intersectVer(linePiece l, linePiece verticalFacingUp) {
	point iPoint = lineLineIntersection(l, verticalFacingUp);
	bool result = (iPoint.y >= verticalFacingUp.a.y && iPoint.y <= verticalFacingUp.b.y)
	|| (iPoint.y >= verticalFacingUp.b.y && iPoint.y <= verticalFacingUp.a.y);
	//if (result) cerr << "vertical " << iPoint << endl;
	return result;
}
// I'm a rebel: I mirror the setup in the line y=0, as it's what normal mathematicians do and it doesn't matter anyway.
enum Corner { BottomLeft, BottomRight, TopRight, TopLeft };
Corner next(Corner c) { switch (c) { case BottomLeft: return BottomRight; case BottomRight: return TopRight; case TopRight: return TopLeft; default: return BottomLeft; } }
bool isNextHor(Corner c) { switch (c) { case BottomLeft: return true; case BottomRight: return false; case TopRight: return true; default: return false; } }
point pedestalCorner(Corner c) {
	switch (c) {
	case BottomLeft: return point(X, Y);
	case BottomRight: return point(X+Ws, Y);
	case TopRight: return point(X+Ws, Y+Ws);
	default: return point(X, Y+Ws);
} }
linePiece bottomPedestal() { return linePiece(pedestalCorner(BottomLeft), pedestalCorner(BottomRight)); }
linePiece topPedestal() { return linePiece(pedestalCorner(TopLeft), pedestalCorner(TopRight)); }
linePiece leftPedestal() { return linePiece(pedestalCorner(BottomLeft), pedestalCorner(TopLeft)); }
linePiece rightPedestal() { return linePiece(pedestalCorner(BottomRight), pedestalCorner(TopRight)); }

enum Side { BottomSide, RightSide, TopSide, LeftSide };
Side getSide(int index) {
	if (0 <= index && index < W) return BottomSide; else index -= W;
	if (0 <= index && index < L) return RightSide; else index -= L;
	if (0 <= index && index < W) return TopSide; else index -= W;
	return LeftSide;
}
int correctIndexForSide(Side s, int index) { switch (s) { case BottomSide: return index; case RightSide: return index - W; case TopSide: return index - W - L; default: return index - W - L - W; } }
point getPillar(int index) {
	Side s = getSide(index); index = correctIndexForSide(s, index);
	switch (s) {
	case BottomSide: return point(index, 0.0);
	case RightSide: return point(W, index);
	case TopSide: return point(W - index, L);
	default: return point(0.0, L - index);
	}
}
point getSideCorner(Corner c) {
	switch (c) {
	case BottomLeft: return point(0.0, 0.0);
	case BottomRight: return point(W, 0.0);
	case TopRight: return point(W, L);
	default: return point(0.0, L);
} }
linePiece getSideLine(Side s) {
	switch (s) {
	case BottomSide: return linePiece(getSideCorner(BottomLeft), getSideCorner(BottomRight));
	case RightSide: return linePiece(getSideCorner(BottomRight), getSideCorner(TopRight));
	case TopSide: return linePiece(getSideCorner(TopRight), getSideCorner(TopLeft));
	default: return linePiece(getSideCorner(TopLeft), getSideCorner(BottomLeft));
} }
linePiece getSideLine(int index) {
	return getSideLine(getSide(index));
}
bool lineIsValid(int i, int j) {
	if (i == j) return false;
	linePiece line(getPillar(i), getPillar(j));
	if (intersectHor(line, bottomPedestal())) return false;
	if (intersectHor(line, topPedestal())) return false;
	if (intersectVer(line, leftPedestal())) return false;
	if (intersectVer(line, rightPedestal())) return false;
	return true;
}

bool glances(Corner c, int index) {
	point pillar = getPillar(index);
	point cp = pedestalCorner(c);
	
	// Handle the case where the diagonal of the square goes through the pillar
	point farCorner = pedestalCorner(next(next(c)));
	linePiece sideLine = getSideLine(getSide(index));
	linePiece diagonal(cp, farCorner);
	point maybePillar = lineLineIntersection(sideLine, diagonal);
	if (pillar.almostEqual(maybePillar)) { //cerr << "diagonal case." << endl;
	return false; }
	//else { cerr << "Not diagonal (" << pillar << " vs " << maybePillar << ", with " << cp << " and " << farCorner << ")" << endl; }
	
	linePiece l(pillar, cp);
	linePiece otherLine1(pedestalCorner(next(c)), pedestalCorner(next(next(c))));
	linePiece otherLine2(pedestalCorner(next(next(c))), pedestalCorner(next(next(next(c)))));
	if (isNextHor(next(c))) {
		if (intersectHor(l, otherLine1)) { //cerr << l << " intersects with " << otherLine1 << endl;
		return false; }
	} else {
		if (intersectVer(l, otherLine1)) { //cerr << l << " intersects with " << otherLine1 << endl;
		return false; }
	}
	if (isNextHor(next(next(c)))) {
		if (intersectHor(l, otherLine2)) { //cerr << l << " intersects with " << otherLine2 << endl;
		return false; }
	} else {
	    if (intersectVer(l, otherLine2)) { //cerr << l << " intersects with " << otherLine2 << endl;
		return false; }
	}
	return true;
}
point glancingPointA(int index) {
	if (glances(BottomLeft, index)) return pedestalCorner(BottomLeft);
	if (glances(TopLeft, index)) return pedestalCorner(TopLeft);
	return pedestalCorner(BottomRight);
}
point glancingPointB(int index) {
	if (glances(TopRight, index)) return pedestalCorner(TopRight);
	if (glances(BottomRight, index)) return pedestalCorner(BottomRight);
	return pedestalCorner(TopLeft);
}

linePiece shadowSide(linePiece shadowLine, Side s) {
	if (s != BottomSide && intersectHor(shadowLine, getSideLine(BottomSide))) return getSideLine(BottomSide);
	if (s != TopSide && intersectHor(shadowLine, getSideLine(TopSide))) return getSideLine(TopSide);
	if (s != LeftSide && intersectVer(shadowLine, getSideLine(LeftSide))) return getSideLine(LeftSide);
	return getSideLine(RightSide);
}
point shadowPoint(int index, point glancingPoint) {
	cerr << "Glancing for " << index << ": " << glancingPoint << endl;
	linePiece shadowLine = linePiece(getPillar(index), glancingPoint);
	linePiece sSide = shadowSide(shadowLine, getSide(index));
	return lineLineIntersection(shadowLine, sSide);
}
int firstIndexPastShadowPoint(point sp) {
	cerr << "Shadow: " << sp << endl;
	if (abs(sp.x - 0.0) < 1e-4) { cerr << 1 << endl; return (int)ceil(sp.y); }
	if (abs(sp.y - W) < 1e-4) { cerr << 2 << endl; return W + (int)ceil(sp.x); }
	if (abs(sp.x - L) < 1e-4) { cerr << 3 << endl; return W + L + (W - (int)floor(sp.y)); }
	cerr << 4 << endl; return W + L + W + (L - (int)floor(sp.x));
}

struct range { range(int start, int end) : start(start), end(end) {} int start; int end;
int newEnd() { return end + nrIndices(); }
int size() { return clamp(newEnd() - start); }
bool contains(int i) { return start <= i && i <= end; }
int overlap(range other)
{
	bool overlap = other.start < newEnd() && start < other.newEnd(); if (!overlap) return 0;
	if (other.contains(start) && other.contains(newEnd())) return size();
	if (contains(other.start) && contains(other.newEnd())) return other.size();
	if (start < other.start) return newEnd() - other.start;
	return other.newEnd() - start;
}
friend ostream& operator<<(ostream& o, range p) { return o << "(" << p.start << ", " << p.end << ")"; }
friend ostream& operator<<(ostream& o, std::pair<range, bool> p) { if (p.second) { return o << "(" << p.first.start << ", " << p.first.end << ")"; } else { return o << "(empty range)"; } }
};
std::pair<range, bool> shadowRange(int i) {
	int firstIndexPastShadowPointOfI = firstIndexPastShadowPoint(shadowPoint(i, glancingPointA(i))); 
	int secondIndexPastShadowPointOfI = firstIndexPastShadowPoint(shadowPoint(i, glancingPointB(i)));
	cerr << "shadow indices: " << firstIndexPastShadowPointOfI << ", " << secondIndexPastShadowPointOfI << endl;
	
	// Handle empty range
	if (firstIndexPastShadowPointOfI == secondIndexPastShadowPointOfI) return make_pair(range(0, 0), false);
	
	int startIndex = clamp(firstIndexPastShadowPointOfI - i) > clamp(secondIndexPastShadowPointOfI - i) ? secondIndexPastShadowPointOfI : firstIndexPastShadowPointOfI;
	return make_pair(range(startIndex, (startIndex == firstIndexPastShadowPointOfI ? secondIndexPastShadowPointOfI : firstIndexPastShadowPointOfI) - 1), true);
}

int nrOfValidTrianglesGivenLine(int i, int j) {
	std::pair<range, bool> shadowIRange = shadowRange(i);
	std::pair<range, bool> shadowJRange = shadowRange(j);
	int iSize = shadowIRange.second ? shadowIRange.first.size() : 0;
	int jSize = shadowJRange.second ? shadowJRange.first.size() : 0;
	cerr << "shadow ranges: " << shadowIRange << ", " << shadowJRange << endl;
	cerr << "Trying line (" << i << ", " << j << "), giving " << nrIndices() << " - " << iSize << " - " << jSize;
	if (iSize == 0 || jSize == 0)
	{
		cerr << "." << endl;
		return nrIndices() - iSize - iSize;
	}
	else
	{
		cerr << " + " << shadowIRange.first.overlap(shadowJRange.first) << "." << endl;
		return nrIndices() - iSize - jSize + shadowIRange.first.overlap(shadowJRange.first);
	}
}

int nchoose3(int n) { if (n < 3) return 0; else return (n-2)*(n-1)*n/6; }
int nrOfTrivialTriangles() { return 2*nchoose3(L)+2*nchoose3(W); }

void doit() {
	cin >> L >> W;
	cin >> X >> Y >> Ws;

	int total = 0;
	for (int i = 0; i < nrIndices(); i++)
		for (int j = i + 1; j < nrIndices(); j++)
			if (lineIsValid(i, j)) {
				total += nrOfValidTrianglesGivenLine(i, j);
			}
			else cerr << "Ignoring line (" << i << ", " << j << ")." << endl;

	cerr << "trivial triangles: " << nrOfTrivialTriangles() << endl;

	cout << (total / 3 - nrOfTrivialTriangles()) << endl;
}

int main () {
	int T;
	cin >> T;
	for (int t = 1; t <= T; t++) {
		doit();
	}
	return 0;
}
